@@ -3,7 +3,7 @@ App::DBBrowser::Table::Substatement::Condition;
 
 use warnings;
 use strict;
-use 5.016;
+use 5.014;
 
 use List::MoreUtils qw( any uniq );
 
@@ -51,7 +51,7 @@ sub add_condition {
     }
 
     COL: while ( 1 ) {
-        my $info = $sf->__info_add_condition( $sql, $stmt, $r_data );
+        my $info = $sf->__info_add_condition( $sql, $clause, $stmt, $r_data );
         # Choose
         my $col = $tc->choose(
             [ @pre, @$cols ],
@@ -92,11 +92,8 @@ sub add_condition {
             $sql->{$stmt} .= ")";
             next COL;
         }
-        if ( @bu == 1 || $sql->{$stmt} =~ /\(\z/ ) {
-            $AND_OR = '';
-        }
-        else {
-            my $info = $sf->__info_add_condition( $sql, $stmt, $r_data );
+        if ( @bu > 1 && $sql->{$stmt} !~ /\(\z/ ) {
+            my $info = $sf->__info_add_condition( $sql, $clause, $stmt, $r_data );
             # Choose
             my $choice = $tc->choose(
                 [ undef, "AND", "OR" ],
@@ -109,6 +106,9 @@ sub add_condition {
             }
             $AND_OR = ' ' . $choice;
         }
+        else {
+            $AND_OR = '';
+        }
         if ( $col eq '(' ) {
             $sql->{$stmt} .= $AND_OR . " (";
             next COL;
@@ -138,8 +138,6 @@ sub add_condition {
 
 sub __add_operator_and_value {
     my ( $sf, $sql, $clause, $stmt, $col, $r_data ) = @_;
-    my $driver = $sf->{i}{driver};
-    my $dbms = $sf->{i}{dbms};
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
     my @operators = @{$sf->{o}{G}{operators}};
@@ -148,24 +146,16 @@ sub __add_operator_and_value {
         $sql->{$stmt} =~ s/\s\z//;
         @operators = ( "EXISTS", "NOT EXISTS" );
     }
-    elsif ( $dbms eq 'SQLite' ) {
+    elsif ( $sf->{i}{driver} eq 'SQLite' ) {
         @operators = grep { ! /^(?:ANY|ALL)\z/ } @operators;
-        @operators = grep { ! /REGEXP/ } @operators if $driver eq 'ODBC';
     }
-    elsif ( $dbms eq 'Firebird' ) {
+    elsif ( $sf->{i}{driver} eq 'Firebird' ) {
         @operators = uniq map { s/REGEXP(?:_i)?\z/SIMILAR TO/; $_ } @operators;
     }
-    elsif ( $dbms eq 'Informix' ) {
+    elsif ( $sf->{i}{driver} eq 'Informix' ) {
         @operators = uniq map { s/REGEXP(?:_i)?\z/MATCHES/; $_ } @operators;
     }
-
-    elsif ( $dbms eq 'MSSQL' ) {
-        my $major_server_version = $ax->major_server_version();
-        if ( $major_server_version < 17 ) {
-            @operators = grep { ! /REGEXP/ } @operators;
-        }
-    }
-    elsif ( $dbms eq 'other' ) {
+    elsif ( $sf->{i}{driver} eq 'ODBC' ) {
         @operators = grep { ! /REGEXP/ } @operators;
     }
     my $bu_stmt = $sql->{$stmt};
@@ -177,7 +167,7 @@ sub __add_operator_and_value {
         #}
         #else {
             my @pre = ( undef );
-            my $info = $sf->__info_add_condition( $sql, $stmt, $r_data );
+            my $info = $sf->__info_add_condition( $sql, $clause, $stmt, $r_data );
             # Choose
             $operator = $tc->choose(
                 [ @pre, @operators ],
@@ -193,7 +183,7 @@ sub __add_operator_and_value {
         if ( $operator =~ /(?:REGEXP(?:_i)?|SIMILAR\sTO)\z/ ) {
             my $not_match = $operator =~ /^NOT/ ? 1 : 0;
             my $case_sensitive = $operator =~ /REGEXP_i\z/ ? 0 : 1;
-            my $regex_op = $sf->__pattern_match( $sql, $col, $not_match, $case_sensitive );
+            my $regex_op = $sf->__pattern_match( $col, $not_match, $case_sensitive );
             if ( ! $regex_op ) {
                 next OPERATOR if @operators > 1;
                 return;
@@ -207,7 +197,7 @@ sub __add_operator_and_value {
         elsif ( $operator =~ /^(?:ALL|ANY)\z/) {
             my @comb_op = ( "= $operator", "$not_equal $operator", "> $operator", "< $operator", ">= $operator", "<= $operator" );
             my @pre = ( undef );
-            my $info = $sf->__info_add_condition( $sql, $stmt, $r_data );
+            my $info = $sf->__info_add_condition( $sql, $clause, $stmt, $r_data );
             # Choose
             $operator = $tc->choose(
                 [ @pre, @comb_op ],
@@ -245,7 +235,7 @@ sub __add_operator_and_value {
 
 
 sub __info_add_condition {
-    my ( $sf, $sql, $stmt, $r_data ) = @_;
+    my ( $sf, $sql, $clause, $stmt, $r_data ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $info = $ax->get_sql_info( $sql );
     if ( @{$r_data//[]} ) {
@@ -259,7 +249,6 @@ sub __info_add_condition {
 
 sub read_and_add_value {
     my ( $sf, $sql, $clause, $stmt, $col, $operator, $r_data ) = @_;
-    my $dbms = $sf->{i}{dbms};
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $is_numeric = $ax->is_numeric( $sql, $col );
@@ -334,10 +323,10 @@ sub read_and_add_value {
             $sql->{$stmt} =~ s/ \? (?=\sESCAPE\s'\\'\z) /$value/x;
         }
         elsif ( $operator =~ /REGEXP(?:_i)?\z/ ) {
-            if ( $dbms eq 'SQLite' ) {
+            if ( $sf->{i}{driver} eq 'SQLite' ) {
                 $sql->{$stmt} =~ s/ (?<=\sREGEXP\() \? (?=,\Q$col\E,[01]\)\z) /$value/x;
             }
-            elsif ( $dbms =~ /^(?:DB2|Oracle|MSSQL)\z/ ) {
+            elsif ( $sf->{i}{driver} =~ /^(?:DB2|Oracle)\z/ ) {
                 $sql->{$stmt} =~ s/ \?  (?=,'[ci]'\)\z) /$value/x;
             }
             else {
@@ -378,7 +367,7 @@ sub __choose_a_column {
     my @choices = @{$sql->{cols_join_condition}};
 
     COL: while ( 1 ) {
-        my $info = $sf->__info_add_condition( $sql, $stmt, $r_data );
+        my $info = $sf->__info_add_condition( $sql, $clause, $stmt, $r_data );
         # Choose
         my $col = $tc->choose(
             [ @pre, @choices ],
@@ -405,9 +394,9 @@ sub __choose_a_column {
 
 
 sub __pattern_match {
-    my ( $sf, $sql, $col, $not_match, $case_sensitive ) = @_;
-    my $dbms = $sf->{i}{dbms};
-    if ( $dbms eq 'SQLite' ) {
+    my ( $sf, $col, $not_match, $case_sensitive ) = @_;
+    my $driver = $sf->{i}{driver};
+    if ( $driver eq 'SQLite' ) {
         if ( $not_match ) {
             return sprintf " NOT REGEXP(?,%s,%d)", $col, $case_sensitive;
         }
@@ -415,7 +404,7 @@ sub __pattern_match {
             return sprintf " REGEXP(?,%s,%d)", $col, $case_sensitive;
         }
     }
-    elsif ( $dbms =~ /^(?:mysql|MariaDB)\z/ ) {
+    elsif ( $driver =~ /^(?:mysql|MariaDB)\z/ ) {
         if ( $not_match ) {
             return " $col NOT REGEXP"        if ! $case_sensitive;
             return " $col NOT REGEXP BINARY" if   $case_sensitive;
@@ -425,19 +414,17 @@ sub __pattern_match {
             return " $col REGEXP BINARY" if   $case_sensitive;
         }
     }
-    elsif ( $dbms eq 'Pg' ) {
-        my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-        my $col = $ax->pg_column_to_text( $sql, $col );
+    elsif ( $driver eq 'Pg' ) {
         if ( $not_match ) {
-            return " $col !~*" if ! $case_sensitive;
-            return " $col !~"  if   $case_sensitive;
+            return " ${col}::text !~*" if ! $case_sensitive; ##
+            return " ${col}::text !~"  if   $case_sensitive;
         }
         else {
-            return " $col ~*" if ! $case_sensitive;
-            return " $col ~"  if   $case_sensitive;
+            return " ${col}::text ~*" if ! $case_sensitive;
+            return " ${col}::text ~"  if   $case_sensitive;
         }
     }
-    elsif ( $dbms eq 'Firebird' ) {
+    elsif ( $driver eq 'Firebird' ) {
         if ( $not_match ) {
             return " $col NOT SIMILAR TO ? ESCAPE '\\'";
         }
@@ -445,7 +432,7 @@ sub __pattern_match {
             return " $col SIMILAR TO ? ESCAPE '\\'";
         }
     }
-    elsif ( $dbms =~ /^(?:DB2|Oracle|MSSQL)\z/ ) {
+    elsif ( $driver =~ /^(?:DB2|Oracle)\z/ ) {
         if ( $not_match ) {
             return " NOT REGEXP_LIKE($col,?,'i')" if ! $case_sensitive;
             return " NOT REGEXP_LIKE($col,?,'c')" if   $case_sensitive;
@@ -458,7 +445,6 @@ sub __pattern_match {
 }
 
 
-
 # The pattern must match the entire string:
 #
 # SIMILAR TO:   %   _       no default Escape
